@@ -64,15 +64,24 @@ class UsageStatisticsHandler(object):
         self._data_docs_sites_anonymizer = DataDocsSiteAnonymizer(data_context_id)
         self._batch_anonymizer = BatchAnonymizer(data_context_id)
         self._expectation_suite_anonymizer = ExpectationSuiteAnonymizer(data_context_id)
-        self._sigterm_handler = signal.signal(signal.SIGTERM, self._teardown)
-        self._sigint_handler = signal.signal(signal.SIGINT, self._teardown)
+        try:
+            self._sigterm_handler = signal.signal(signal.SIGTERM, self._teardown)
+        except ValueError:
+            # if we are not the main thread, we don't get to ask for signal handling.
+            self._sigterm_handler = None
+        try:
+            self._sigint_handler = signal.signal(signal.SIGINT, self._teardown)
+        except ValueError:
+            # if we are not the main thread, we don't get to ask for signal handling.
+            self._sigint_handler = None
+
         atexit.register(self._close_worker)
 
     def _teardown(self, signum: int, frame):
         self._close_worker()
-        if signum == signal.SIGTERM:
+        if signum == signal.SIGTERM and self._sigterm_handler:
             self._sigterm_handler(signum, frame)
-        if signum == signal.SIGINT:
+        if signum == signal.SIGINT and self._sigint_handler:
             self._sigint_handler(signum, frame)
 
     def _close_worker(self):
@@ -190,7 +199,6 @@ class UsageStatisticsHandler(object):
                 message, schema=usage_statistics_record_schema
             ):
                 return
-
             self._message_queue.put(message)
         # noinspection PyBroadException
         except Exception as e:
@@ -235,6 +243,10 @@ def usage_statistics_enabled_method(
 
         @wraps(func)
         def usage_statistics_wrapped_method(*args, **kwargs):
+            # if a function like `build_data_docs()` is being called as a `dry_run`
+            # then we dont want to emit usage_statistics. We just return the function without sending a usage_stats message
+            if "dry_run" in kwargs and kwargs["dry_run"]:
+                return func(*args, **kwargs)
             # Set event_payload now so it can be updated below
             event_payload = {}
             message = {"event_payload": event_payload, "event": event_name}
@@ -251,8 +263,10 @@ def usage_statistics_enabled_method(
                 message["success"] = True
                 if handler is not None:
                     handler.emit(message)
-            except Exception:
+            # except Exception:
+            except Exception as e:
                 message["success"] = False
+                handler = get_usage_statistics_handler(args)
                 if handler:
                     handler.emit(message)
                 raise
@@ -357,6 +371,29 @@ def edit_expectation_suite_usage_statistics(data_context, expectation_suite_name
     return payload
 
 
+def add_datasource_usage_statistics(data_context, name, **kwargs):
+    try:
+        data_context_id = data_context.data_context_id
+    except AttributeError:
+        data_context_id = None
+
+    try:
+        datasource_anonymizer = (
+            data_context._usage_statistics_handler._datasource_anonymizer
+        )
+    except Exception:
+        datasource_anonymizer = DatasourceAnonymizer(data_context_id)
+
+    payload = {}
+    try:
+        payload = datasource_anonymizer.anonymize_datasource_info(name, kwargs)
+    except Exception:
+        logger.debug(
+            "add_datasource_usage_statistics: Unable to create add_datasource_usage_statistics payload field"
+        )
+    return payload
+
+
 def send_usage_message(data_context, event, event_payload=None, success=None):
     """send a usage statistics message."""
     try:
