@@ -5,17 +5,11 @@ html_files = glob.glob("tests/**/output/**/*.html", recursive=True)
 
 html_list = ""
 for f_ in html_files:
-    html_list += '\t<li><a href="{}">{}</li>\n'.format(
-        f_[6:],
-        f_.split(".")[-2],
-    )
+    html_list += '\t<li><a href="{}">{}</li>\n'.format(f_[6:], f_.split(".")[-2],)
 
 json_list = ""
 for f_ in json_files:
-    json_list += '\t<li><a href="{}">{}</li>\n'.format(
-        f_[6:],
-        f_.split(".")[-2],
-    )
+    json_list += '\t<li><a href="{}">{}</li>\n'.format(f_[6:], f_.split(".")[-2],)
 
 html_file = """
 <html>
@@ -32,8 +26,7 @@ html_file = """
 </body>
 </html>
 """.format(
-    html_list,
-    json_list
+    html_list, json_list
 )
 
 print(html_file)
