@@ -581,15 +581,10 @@ def test_checkpoint_run_on_non_existent_validation_operator(
         in stdout
     )
 
-    assert mock_emit.call_count == 2
-    assert mock_emit.call_args_list == [
-        mock.call(
-            {"event_payload": {}, "event": "data_context.__init__", "success": True}
-        ),
-        mock.call(
-            {"event": "cli.checkpoint.run", "event_payload": {}, "success": False}
-        ),
-    ]
+    assert mock_emit.call_count == 3
+    assert mock_emit.call_args_list[0].args[0]["success"] == True
+    assert mock_emit.call_args_list[1].args[0]["success"] == False
+    assert mock_emit.call_args_list[2].args[0]["success"] == False
 
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
