@@ -4,10 +4,12 @@ import pytest
 from click.testing import CliRunner
 
 from great_expectations.cli import cli
-from great_expectations.util import gen_directory_tree_str
+from great_expectations.cli.python_subprocess import (
+    execute_shell_command_with_progress_polling,
+)
+from great_expectations.util import gen_directory_tree_str, is_library_loadable
 from tests.cli.test_cli import yaml
 from tests.cli.utils import assert_no_logging_messages_or_tracebacks
-from tests.test_utils import is_library_installed
 
 
 def _library_not_loaded_test(
@@ -39,10 +41,16 @@ of this config file: great_expectations/uncommitted/config_variables.yml"""
         in stdout
     )
     assert (
-        "Great Expectations relies on the library `{}`".format(library_import_name)
+        f"""Great Expectations relies on the library `{library_import_name}` to connect to your data, \
+but the package `{library_name}` containing this library is not installed.
+    Would you like Great Expectations to try to execute `pip install {library_name}` for you?"""
+        in stdout
+    )
+    assert (
+        f"""\nOK, exiting now.
+    - Please execute `pip install {library_name}` before trying again."""
         in stdout
     )
-    assert "Please `pip install {}` before trying again".format(library_name) in stdout
 
     assert "Profiling" not in stdout
     assert "Building" not in stdout
@@ -91,40 +99,93 @@ great_expectations/
 
 
 @pytest.mark.skipif(
-    is_library_installed("pymysql"), reason="requires pymysql to NOT be installed"
+    is_library_loadable(library_name="sqlalchemy"),
+    reason="requires sqlalchemy to NOT be installed",
+)
+def test_init_install_sqlalchemy(caplog, tmp_path_factory):
+    """WARNING: THIS TEST IS AWFUL AND WE HATE IT."""
+    # This test is as much about changing the entire test environment with side effects as it is about actually testing
+    # the observed behavior.
+    library_import_name = "sqlalchemy"
+    library_name = "sqlalchemy"
+
+    cli_input = "\n\n2\nn\n"
+
+    basedir = tmp_path_factory.mktemp("test_cli_init_diff")
+    basedir = str(basedir)
+    os.chdir(basedir)
+
+    runner = CliRunner(mix_stderr=False)
+    result = runner.invoke(
+        cli, ["init", "--no-view"], input=cli_input, catch_exceptions=False
+    )
+    stdout = result.output
+
+    assert "Always know what to expect from your data" in stdout
+    assert "What data would you like Great Expectations to connect to" in stdout
+    assert (
+        f"""Great Expectations relies on the library `{library_import_name}` to connect to your data, \
+but the package `{library_name}` containing this library is not installed.
+    Would you like Great Expectations to try to execute `pip install {library_name}` for you?"""
+        in stdout
+    )
+
+    # NOW, IN AN EVIL KNOWN ONLY TO SLEEPLESS PROGRAMMERS, WE USE OUR UTILITY TO INSTALL SQLALCHEMY
+    _ = execute_shell_command_with_progress_polling("pip install sqlalchemy")
+
+
+@pytest.mark.skipif(
+    is_library_loadable(library_name="pymysql"),
+    reason="requires pymysql to NOT be installed",
 )
 def test_cli_init_db_mysql_without_library_installed_instructs_user(
     caplog, tmp_path_factory
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n1\nmy_db\n", "pymysql", "pymysql", caplog
+        tmp_path_factory, "\n\n2\n1\nmy_db\nn\n", "pymysql", "pymysql", caplog
     )
 
 
 @pytest.mark.skipif(
-    is_library_installed("psycopg2"), reason="requires psycopg2 to NOT be installed"
+    is_library_loadable(library_name="pyodbc"),
+    reason="requires pyodbc to NOT be installed",
+)
+def test_cli_init_db_mssql_without_library_installed_instructs_user(
+    caplog, tmp_path_factory
+):
+    # TODO: Update to reflect the CLI flow sequence (once it has been implemented) and re-enable.
+    # _library_not_loaded_test(
+    #     tmp_path_factory, "\n\n2\n6\nmy_db\nwrong_ms_sql_server_library\nn\n", "pyodbc", "pyodbc", caplog
+    # )
+    return True
+
+
+@pytest.mark.skipif(
+    is_library_loadable(library_name="psycopg2"),
+    reason="requires psycopg2 to NOT be installed",
 )
 def test_cli_init_db_postgres_without_library_installed_instructs_user(
     caplog, tmp_path_factory,
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n2\nmy_db\n", "psycopg2", "psycopg2", caplog
+        tmp_path_factory, "\n\n2\n2\nmy_db\nn\n", "psycopg2-binary", "psycopg2", caplog
     )
 
 
 @pytest.mark.skipif(
-    is_library_installed("psycopg2"), reason="requires psycopg2 to NOT be installed"
+    is_library_loadable(library_name="psycopg2"),
+    reason="requires psycopg2 to NOT be installed",
 )
 def test_cli_init_db_redshift_without_library_installed_instructs_user(
     caplog, tmp_path_factory,
 ):
     _library_not_loaded_test(
-        tmp_path_factory, "\n\n2\n3\nmy_db\n", "psycopg2", "psycopg2", caplog
+        tmp_path_factory, "\n\n2\n3\nmy_db\nn\n", "psycopg2-binary", "psycopg2", caplog
     )
 
 
 @pytest.mark.skipif(
-    is_library_installed("snowflake"),
+    is_library_loadable(library_name="snowflake.sqlalchemy"),
     reason="requires snowflake-sqlalchemy to NOT be installed",
 )
 def test_cli_init_db_snowflake_without_library_installed_instructs_user(
@@ -132,15 +193,16 @@ def test_cli_init_db_snowflake_without_library_installed_instructs_user(
 ):
     _library_not_loaded_test(
         tmp_path_factory,
-        "\n\n2\n4\nmy_db\n",
+        "\n\n2\n4\nmy_db\nn\n",
         "snowflake-sqlalchemy",
-        "snowflake",
+        "snowflake.sqlalchemy.snowdialect",
         caplog,
     )
 
 
 @pytest.mark.skipif(
-    is_library_installed("pyspark"), reason="requires pyspark to NOT be installed"
+    is_library_loadable(library_name="pyspark"),
+    reason="requires pyspark to NOT be installed",
 )
 def test_cli_init_spark_without_library_installed_instructs_user(
     caplog, tmp_path_factory
@@ -151,15 +213,26 @@ def test_cli_init_spark_without_library_installed_instructs_user(
 
     runner = CliRunner(mix_stderr=False)
     result = runner.invoke(
-        cli, ["init", "--no-view"], input="\n\n1\n2\n", catch_exceptions=False
+        cli, ["init", "--no-view"], input="\n\n1\n2\nn\n", catch_exceptions=False
     )
     stdout = result.output
 
     assert "Always know what to expect from your data" in stdout
     assert "What data would you like Great Expectations to connect to" in stdout
     assert "What are you processing your files with" in stdout
-    assert "Great Expectations relies on the library `pyspark`" in stdout
-    assert "Please `pip install pyspark` before trying again" in stdout
+    assert (
+        f"""Great Expectations relies on the library `pyspark` to connect to your data, \
+but the package `pyspark` containing this library is not installed.
+    Would you like Great Expectations to try to execute `pip install pyspark` for you?"""
+        in stdout
+    )
+    assert (
+        f"""\nOK, exiting now.
+    - Please execute `pip install pyspark` before trying again."""
+        in stdout
+    )
+    # assert "Great Expectations relies on the library `pyspark`" in stdout
+    # assert "Please `pip install pyspark` before trying again" in stdout
 
     assert "Profiling" not in stdout
     assert "Building" not in stdout
