@@ -149,7 +149,7 @@ def test_HtmlSiteStore_S3_backend():
     assert set(
         [
             s3_object_info["Key"]
-            for s3_object_info in boto3.client("s3").list_objects(
+            for s3_object_info in boto3.client("s3").list_objects_v2(
                 Bucket=bucket, Prefix=prefix
             )["Contents"]
         ]
