@@ -1,7 +1,7 @@
 import pytest
 
 import great_expectations.exceptions as gee
-from great_expectations.data_context.util import load_class
+from great_expectations.util import load_class
 
 
 def test_load_class_raises_error_when_module_not_found():
