@@ -124,7 +124,13 @@ def test__create_expectations_for_numeric_column(
     expectation_suite = numeric_high_card_dataset.get_expectation_suite(
         suppress_warnings=True
     )
-    if test_backend in ["PandasDataset", "SparkDFDataset", "postgresql"]:
+    if test_backend in [
+        "PandasDataset",
+        "SparkDFDataset",
+        "postgresql",
+        "mysql",
+        "mssql",
+    ]:
         assert set(
             [
                 expectation.expectation_type
@@ -347,7 +353,7 @@ def test_BasicSuiteBuilderProfiler_with_context(filesystem_csv_data_context):
         "batch_markers",
         "batch_parameters",
         "expectation_suite_name",
-        "great_expectations.__version__",
+        "great_expectations_version",
         "run_id",
         "validation_time",
     }
@@ -488,13 +494,16 @@ def test_snapshot_BasicSuiteBuilderProfiler_on_titanic_in_demo_mode():
         if "partial_unexpected_counts" in result.result:
             result.result.pop("partial_unexpected_counts")
 
-    # Version and RUN-ID will be different
-    del expected_evrs.meta["great_expectations.__version__"]
-    del evrs.meta["great_expectations.__version__"]
+    # Version, run_id, batch id will be different
+    del expected_evrs.meta["great_expectations_version"]
+    del evrs.meta["great_expectations_version"]
+
     del expected_evrs.meta["run_id"]
-    del expected_evrs.meta["batch_kwargs"]["ge_batch_id"]
     del evrs.meta["run_id"]
+
+    del expected_evrs.meta["batch_kwargs"]["ge_batch_id"]
     del evrs.meta["batch_kwargs"]["ge_batch_id"]
+
     del evrs.meta["validation_time"]
 
     assert evrs == expected_evrs
@@ -607,7 +616,7 @@ def test_BasicSuiteBuilderProfiler_uses_all_columns_if_configuration_does_not_ha
                 "expectation_type": "expect_column_values_to_be_unique",
             },
             {
-                "kwargs": {"column": "nulls", "mostly": 0.4714285714285715},
+                "kwargs": {"column": "nulls", "mostly": 0.471},
                 "meta": {"BasicSuiteBuilderProfiler": {"confidence": "very low"}},
                 "expectation_type": "expect_column_values_to_not_be_null",
             },
@@ -908,7 +917,7 @@ def test_BasicSuiteBuilderProfiler_respects_included_expectations_on_pandas(
             },
             {
                 "meta": {"BasicSuiteBuilderProfiler": {"confidence": "very low"}},
-                "kwargs": {"column": "nulls", "mostly": 0.4714285714285715},
+                "kwargs": {"column": "nulls", "mostly": 0.471},
                 "expectation_type": "expect_column_values_to_not_be_null",
             },
         ],
@@ -1085,7 +1094,7 @@ def test_BasicSuiteBuilderProfiler_uses_all_expectations_if_excluded_expectation
                 "meta": {"BasicSuiteBuilderProfiler": {"confidence": "very low"}},
             },
             {
-                "kwargs": {"column": "nulls", "mostly": 0.4714285714285715},
+                "kwargs": {"column": "nulls", "mostly": 0.471},
                 "expectation_type": "expect_column_values_to_not_be_null",
                 "meta": {"BasicSuiteBuilderProfiler": {"confidence": "very low"}},
             },
@@ -1231,7 +1240,7 @@ def test_BasicSuiteBuilderProfiler_uses_all_columns_if_excluded_columns_are_fals
             {
                 "expectation_type": "expect_column_values_to_not_be_null",
                 "meta": {"BasicSuiteBuilderProfiler": {"confidence": "very low"}},
-                "kwargs": {"column": "nulls", "mostly": 0.4714285714285715},
+                "kwargs": {"column": "nulls", "mostly": 0.471},
             },
         ],
     )
@@ -1319,8 +1328,8 @@ def test_snapshot_BasicSuiteBuilderProfiler_on_titanic_with_builder_configuratio
         )
 
         # Version and RUN-ID will be different
-    del expected_evrs.meta["great_expectations.__version__"]
-    del evrs.meta["great_expectations.__version__"]
+    del expected_evrs.meta["great_expectations_version"]
+    del evrs.meta["great_expectations_version"]
     del expected_evrs.meta["run_id"]
     del expected_evrs.meta["batch_kwargs"]["ge_batch_id"]
     del evrs.meta["run_id"]
