@@ -19,7 +19,7 @@ def test_SlackRenderer():
             "success_percent": None,
         },
         meta={
-            "great_expectations.__version__": "v0.8.0__develop",
+            "great_expectations_version": "v0.8.0__develop",
             "data_asset_name": {
                 "datasource": "x",
                 "generator": "y",
@@ -39,7 +39,7 @@ def test_SlackRenderer():
                 "type": "section",
                 "text": {
                     "type": "mrkdwn",
-                    "text": "*Batch Validation Status*: Success :tada:\n*Expectation suite name*: `default`\n*Run ID*: `2019-09-25T060538.829112Z`\n*Batch ID*: `None`\n*Timestamp*: `09/24/2019 23:18:36`\n*Summary*: *0* of *0* expectations were met",
+                    "text": "*Batch Validation Status*: Success :tada:\n*Expectation suite name*: `default`\n*Run ID*: `2019-09-25T060538.829112Z`\n*Batch ID*: `None`\n*Summary*: *0* of *0* expectations were met",
                 },
             },
             {"type": "divider"},
