@@ -4,6 +4,7 @@ import pytest
 
 import great_expectations as ge
 from great_expectations.core.util import nested_update
+from great_expectations.dataset.util import check_sql_engine_dialect
 from great_expectations.util import lint_code
 
 
@@ -11,16 +12,20 @@ def test_validate_non_dataset(file_data_asset, empty_expectation_suite):
     with pytest.raises(
         ValueError, match=r"The validate util method only supports dataset validations"
     ):
-        ge.validate(
-            file_data_asset,
-            empty_expectation_suite,
-            data_asset_class=ge.data_asset.FileDataAsset,
-        )
+        with pytest.warns(
+            Warning,
+            match="No great_expectations version found in configuration object.",
+        ):
+            ge.validate(
+                file_data_asset,
+                empty_expectation_suite,
+                data_asset_class=ge.data_asset.FileDataAsset,
+            )
 
 
 def test_validate_dataset(dataset, basic_expectation_suite):
     res = ge.validate(dataset, basic_expectation_suite)
-    assert res.success is True
+    # assert res.success is True  # will not be true for mysql, where "infinities" column is missing
     assert res["statistics"]["evaluated_expectations"] == 4
     if isinstance(dataset, ge.dataset.PandasDataset):
         res = ge.validate(
@@ -40,7 +45,10 @@ def test_validate_dataset(dataset, basic_expectation_suite):
                 data_asset_class=ge.dataset.SqlAlchemyDataset,
             )
 
-    elif isinstance(dataset, ge.dataset.SqlAlchemyDataset):
+    elif (
+        isinstance(dataset, ge.dataset.SqlAlchemyDataset)
+        and dataset.sql_engine_dialect.name.lower() != "mysql"
+    ):
         res = ge.validate(
             dataset,
             expectation_suite=basic_expectation_suite,
@@ -58,6 +66,28 @@ def test_validate_dataset(dataset, basic_expectation_suite):
                 data_asset_class=ge.dataset.PandasDataset,
             )
 
+    elif (
+        isinstance(dataset, ge.dataset.SqlAlchemyDataset)
+        and dataset.sql_engine_dialect.name.lower() == "mysql"
+    ):
+        # mysql cannot use the infinities column
+        res = ge.validate(
+            dataset,
+            expectation_suite=basic_expectation_suite,
+            data_asset_class=ge.dataset.SqlAlchemyDataset,
+        )
+        assert res.success is False
+        assert res["statistics"]["evaluated_expectations"] == 4
+        with pytest.raises(
+            ValueError,
+            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
+        ):
+            ge.validate(
+                dataset,
+                expectation_suite=basic_expectation_suite,
+                data_asset_class=ge.dataset.PandasDataset,
+            )
+
     elif isinstance(dataset, ge.dataset.SparkDFDataset):
         res = ge.validate(
             dataset, basic_expectation_suite, data_asset_class=ge.dataset.SparkDFDataset
@@ -83,11 +113,14 @@ def test_validate_using_data_context(
         data_context_parameterized_expectation_suite._evaluation_parameter_dependencies_compiled
         is False
     )
-    res = ge.validate(
-        dataset,
-        expectation_suite_name="my_dag_node.default",
-        data_context=data_context_parameterized_expectation_suite,
-    )
+    with pytest.warns(
+        Warning, match=r"This configuration object was built using version"
+    ):
+        res = ge.validate(
+            dataset,
+            expectation_suite_name="my_dag_node.default",
+            data_context=data_context_parameterized_expectation_suite,
+        )
 
     # Since the handling of evaluation parameters is no longer happening without an action,
     # the context should still be not compiles after validation.
@@ -105,11 +138,14 @@ def test_validate_using_data_context_path(
     dataset, data_context_parameterized_expectation_suite
 ):
     data_context_path = data_context_parameterized_expectation_suite.root_directory
-    res = ge.validate(
-        dataset,
-        expectation_suite_name="my_dag_node.default",
-        data_context=data_context_path,
-    )
+    with pytest.warns(
+        Warning, match=r"This configuration object was built using version"
+    ):
+        res = ge.validate(
+            dataset,
+            expectation_suite_name="my_dag_node.default",
+            data_context=data_context_path,
+        )
 
     # We should have now found the right suite with expectations to evaluate
     assert res.success is False
